#!/opt/anaconda1anaconda2anaconda3/bin/python
# File created 8 Sep 2010

__author__ = "William A. Walters"
__copyright__ = "Copyright 2010, The PrimerProspector project"
__credits__ = ["William A. Walters", "Greg Caporaso", "Rob Knight"]
__license__ = "GPL"
__version__ = "1.0.1-release"
__maintainer__ = "William A. Walters"
__email__ = "william.a.walters@colorado.edu"
__status__ = "Release"

from cogent.util.misc import parse_command_line_parameters, create_dir
from optparse import make_option

from primerprospector.clean_fasta import filter_fasta



script_info={}
script_info['brief_description']="""Filters input fasta file to remove gaps and 'U' characters."""
script_info['script_description']="""This module will filter out gap characters ('.' and '-'), spaces, and/or uracil characters ('U') from an input fasta file(s).  The module can also capitalize the characters in the filtered file(s).  This should be done for fasta files to be utilized with analyze_primers.py or any downstream module requring input fasta files. """

script_info['script_usage']=[]
script_info['script_usage'].append(("""Standard Example usage:""","""""","""%prog [options] {-f input_fasta_filepath [required] }"""))
script_info['script_usage'].append(("""Keep gap characters in two aligned fasta files, but allow all other filtering:""","""""","""clean_fasta.py -f input_aligned_seqs1.fasta:input_aligned_seqs2.fasta -g"""))



script_info['output_description']="""Output fasta file(s) generated by this module will have a '_filtered.fasta' appended to the original fasta file name."""


script_info['required_options']=[\
    # input fasta filepath(s)
    make_option('-f', '--fasta_seqs',
        help='Target fasta file(s) to filter.'+\
        ' Separate multiple files with a colon.')]
                    
script_info['optional_options']=[\
    # Specify output directory
    make_option('-o', '--output_dir',
        help='Output directory for filtered fasta file(s). '+\
        '[default: %default]', default="."),
        
    make_option('-g', '--gap_chars',
        help='Filter gap characters "." and "-" [default: %default]',
        default = True, action = "store_false"),
        
    make_option('-s', '--space_chars',
        help='Filter space characters. [default: %default]',
        default = True, action = "store_false"),
        
    make_option('-u', '--convert_uracil',
        help='Convert Uracil "U" characters to "T". [default: %default]',
        default = True, action = "store_false"),
        
    make_option('-c', '--cap_seqs',
        help='Capitalize filtered sequences [default: %default]',
        default = True, action = "store_false")]
         

script_info['version'] = __version__

def main():

    option_parser, opts, args = parse_command_line_parameters(**script_info)
    
    fasta_seqs = opts.fasta_seqs
    output_dir = opts.output_dir
    gap_chars = opts.gap_chars
    space_chars = opts.space_chars
    convert_uracil = opts.convert_uracil
    cap_seqs = opts.cap_seqs
    
    # Create output directory if it does not exist
    create_dir(output_dir)
    
    filter_fasta(fasta_seqs, output_dir, gap_chars, space_chars, convert_uracil,
     cap_seqs)
    
if __name__ == "__main__":
    main()
